====================
IRC Channel Policies
====================

Projects associated with OpenStack are encouraged to use IRC channels
for communication.  The ``#openstack`` channel is available for
discussion of any OpenStack related topic, and ``#openstack-dev``
likewise for development topics.

Many projects also have their own channels, though this is not
required. The ``#openstack-tc`` channel is used by members of the
Technical Committee for discussions related to OpenStack governance and
everyone in the community is welcome to join and participate in the
conversations or when they have a question or a concern.

As a community we strive for open communication that accommodates many
schedules, styles, cultures, and preferences.  We maintain IRC
channels for real-time communication as a primary use-case.  But,
since asynchronous communication is also necessary considering our
community lives around the globe, we want logs of that communication
with expectations that all our IRC channels are open to everyone.

All OpenStack related channels shall be logged and made publicly
accessible and attempts to notify channel users of that fact shall be
undertaken.
